import {
  Box,
  Text,
  Input,
  VStack,
  InputGroup,
  InputRightElement,
  Spinner,
  BoxProps,
  Flex,
} from "@chakra-ui/react";
import React from "react";
import PlacesAutocomplete, {
  geocodeByAddress,
  getLatLng,
} from "react-places-autocomplete";

interface IProps extends BoxProps {
  setLocation: (street: string, coordinates: google.maps.LatLngLiteral) => void;
}

const AutocompleteGeocoding = ({ setLocation }: IProps): React.ReactElement => {
  const [address, setAddress] = React.useState("");

  const handleSelect = async (value: string) => {
    const results = await geocodeByAddress(value);
    const latLng = await getLatLng(results[0]);
    setAddress(value);
    setLocation(value, latLng);
  };

  return (
    <PlacesAutocomplete
      value={address}
      onChange={setAddress}
      onSelect={handleSelect}
    >
      {({ getInputProps, suggestions, getSuggestionItemProps, loading }) => (
        <Box w="100%">
          <InputGroup>
            <Input
              {...getInputProps()}
              placeholder="Endereço"
              borderColor="blue.200"
            />
            <InputRightElement>{loading && <Spinner />}</InputRightElement>
          </InputGroup>

          <VStack maxH="100px" overflowY="auto">
            {suggestions.map((suggestion, key) => {
              return (
                <Flex
                  {...getSuggestionItemProps(suggestion)}
                  key={key}
                  w="100%"
                  p="5px"
                  alignItems="center"
                  cursor="pointer"
                  borderRadius="3px"
                  _hover={{ bgColor: "blue.200" }}
                >
                  <Text>{suggestion.description}</Text>
                </Flex>
              );
            })}
          </VStack>
        </Box>
      )}
    </PlacesAutocomplete>
  );
};

export default AutocompleteGeocoding;
