import { useToast, Flex, Box } from "@chakra-ui/react";
import * as reactFontawesome from "@fortawesome/react-fontawesome";
import React, { useEffect, useState } from "react";
import { useHistory } from "react-router-dom";

import { getLoggedUserFromLocalStorage } from "../../utils/utils";

const BottomMenu = (props: { defaultIndex: number }): React.ReactElement => {
  const history = useHistory();
  const toast = useToast();

  const [isAdmin, setIsAdmin] = useState(false);
  const [loggedUserId, setLoggedUserId] = useState("");
  const { defaultIndex } = props;

  const showToastMessage = () => {
    toast({
      title: "A página não existe!",
      status: "error",
      position: "top-right",
      isClosable: true,
    });
  };

  useEffect(() => {
    const loggedUser = getLoggedUserFromLocalStorage();
    setLoggedUserId(loggedUser.id || "0");
    setIsAdmin(loggedUser.type === "ADMIN");
  }, []);

  const onChange = (index: React.SetStateAction<number>) => {
    switch (index) {
      case 0:
        history.push(isAdmin ? "/list-events" : "/events");
        break;
      case 1:
        history.push("/map");
        break;
      case 2:
        history.push("/create-event");
        break;
      case 3:
        history.push(`/profile/${loggedUserId}`);
        break;
      case 4:
        history.push("/registration-request");
        break;
      default:
        showToastMessage();
        break;
    }
  };
  return (
    <div
      style={{
        position: "fixed",
        left: 0,
        bottom: 0,
        width: "100%",
        textAlign: "center",
        zIndex: 999,
      }}
    >
      <Flex
        justifyContent="space-around"
        alignItems="center"
        h="50px"
        bgColor="blue.200"
      >
        <Box cursor="pointer" title="Início" onClick={() => onChange(0)}>
          <reactFontawesome.FontAwesomeIcon
            icon="home"
            size="2x"
            color={defaultIndex === 0 ? "#55cb8b" : "white"}
          />
        </Box>
        <Box cursor="pointer" title="Mapa" onClick={() => onChange(1)}>
          <reactFontawesome.FontAwesomeIcon
            icon="map-marked-alt"
            size="2x"
            color={defaultIndex === 1 ? "#55cb8b" : "white"}
          />
        </Box>
        <Box cursor="pointer" title="Criar Evento" onClick={() => onChange(2)}>
          <reactFontawesome.FontAwesomeIcon
            icon="plus-circle"
            size="2x"
            color={defaultIndex === 2 ? "#55cb8b" : "white"}
          />
        </Box>
        <Box cursor="pointer" title="Perfil" onClick={() => onChange(3)}>
          <reactFontawesome.FontAwesomeIcon
            icon="user"
            size="2x"
            color={defaultIndex === 3 ? "#55cb8b" : "white"}
          />
        </Box>

        {isAdmin && (
          <Box
            cursor="pointer"
            title="Cadastros Pendentes"
            onClick={() => onChange(4)}
          >
            <reactFontawesome.FontAwesomeIcon
              icon="users-cog"
              size="2x"
              color={defaultIndex === 4 ? "#55cb8b" : "white"}
            />
          </Box>
        )}
      </Flex>
    </div>
  );
};

export default BottomMenu;
