import {
  Button,
  Flex,
  Modal,
  ModalBody,
  ModalCloseButton,
  ModalContent,
  ModalFooter,
  ModalHeader,
  ModalOverlay,
  ToastPositionWithLogical,
  useToast,
} from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { useState } from "react";

import { TaskDTO } from "../../model/taskModel";
import { evaluationTask } from "../../services/taskService";

interface IProps {
  open: boolean;
  eventId: string;
  taskId: string;
  close: () => void;
}

const EvaluationModal = ({
  open,
  eventId,
  taskId,
  close,
}: IProps): React.ReactElement => {
  const [selected, setSelected] = useState<number>(0);
  const [loading, setLoading] = useState(false);
  const toast = useToast();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  const evaluate = async () => {
    setLoading(true);
    try {
      const task: TaskDTO = {
        id: taskId,
        evaluationType: selected === 1 ? "POSITIVE" : "NEGATIVE",
      };
      await evaluationTask(eventId, task);
      showToastMessage(
        "Avaliação realizada com sucesoo!",
        "success",
        "top-right"
      );
    } catch (e: any) {
      showToastMessage(e, "error", "top-right");
    }
    setLoading(false);
    setSelected(0);
    close();
  };

  return (
    <Modal isOpen={open} onClose={close} isCentered closeOnOverlayClick={false}>
      <ModalOverlay />
      <ModalContent>
        <ModalHeader>Por favor, avalie a tarefa:</ModalHeader>
        <ModalCloseButton />
        <ModalBody>
          <Flex justifyContent="space-evenly" alignItems="center">
            <Button
              h="40px"
              w="40px"
              p="25px"
              bgColor={selected === 2 ? "blue.200" : "transparent"}
              title="Ruim"
              isDisabled={loading}
              onClick={() => setSelected(2)}
            >
              <FontAwesomeIcon
                icon="thumbs-down"
                size="2x"
                color="#f9c201"
                cursor="pointer"
              />
            </Button>

            <Button
              h="40px"
              w="40px"
              p="25px"
              bgColor={selected === 1 ? "blue.200" : "transparent"}
              title="Boa"
              isDisabled={loading}
              onClick={() => setSelected(1)}
            >
              <FontAwesomeIcon
                icon="thumbs-up"
                size="2x"
                color="#f9c201"
                cursor="pointer"
              />
            </Button>
          </Flex>
        </ModalBody>

        <ModalFooter>
          <Button bgColor="blue.200" color="white" mr={3} onClick={close}>
            Cancelar
          </Button>
          <Button
            variant="ghost"
            isLoading={loading}
            isDisabled={selected <= 0 || selected > 2}
            onClick={() => evaluate()}
          >
            Avaliar
          </Button>
        </ModalFooter>
      </ModalContent>
    </Modal>
  );
};

export default EvaluationModal;
