/* eslint-disable react/jsx-no-undef */
import {
  Box,
  Button,
  Checkbox,
  Modal,
  ModalBody,
  ModalCloseButton,
  ModalContent,
  ModalFooter,
  ModalHeader,
  ModalOverlay,
  useDisclosure,
} from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { useContext, useState } from "react";

import { FilterContext } from "../../contexts/FilterContext";

const EventFilter = (): React.ReactElement => {
  const { filters, updateFilters } = useContext(FilterContext);
  const { isOpen, onOpen, onClose } = useDisclosure();
  const [localFilterUserCreatedEvents, setlocalFilterUserCreatedEvents] =
    useState<boolean>(filters.filterUserCreatedEvents);
  const [
    localFilterUserParticipateEvents,
    setlocalFilterUserParticipateEvents,
  ] = useState<boolean>(filters.filterUserParticipateEvents);

  const clearFilters = () => {
    setlocalFilterUserCreatedEvents(false);
    setlocalFilterUserParticipateEvents(false);
  };

  const applyFilters = () => {
    updateFilters({
      filterUserCreatedEvents: localFilterUserCreatedEvents,
      filterUserParticipateEvents: localFilterUserParticipateEvents,
    });
    onClose();
  };

  return (
    <>
      <Box onClick={onOpen} ml="10px">
        <FontAwesomeIcon icon="filter" size="lg" color="#f9c201" />
      </Box>

      <Modal isOpen={isOpen} onClose={onClose} isCentered>
        <ModalOverlay />
        <ModalContent>
          <ModalHeader>Filtro de Eventos</ModalHeader>
          <ModalCloseButton />
          <ModalBody>
            <Checkbox
              isChecked={localFilterUserCreatedEvents}
              colorScheme="green"
              onChange={(e) =>
                setlocalFilterUserCreatedEvents(e.target.checked)
              }
            >
              Listar meus eventos criados
            </Checkbox>
            <Checkbox
              isChecked={localFilterUserParticipateEvents}
              colorScheme="green"
              onChange={(e) =>
                setlocalFilterUserParticipateEvents(e.target.checked)
              }
            >
              Listar os eventos que eu participo
            </Checkbox>
          </ModalBody>

          <ModalFooter>
            <Button
              bgColor="blue.200"
              color="white"
              mr={3}
              onClick={() => clearFilters()}
            >
              Limpar
            </Button>
            <Button variant="ghost" onClick={() => applyFilters()}>
              Aplicar
            </Button>
          </ModalFooter>

          {/* <ModalFooter>
            <Button colorScheme="green" mr={3} onClick={onClose}>
              Aplicar
            </Button>
            <Button colorScheme="blue" mr={3} onClick={onClose}>
              Close
            </Button>
          </ModalFooter> */}
        </ModalContent>
      </Modal>
    </>
  );
};

export default EventFilter;
