import { Box, Text, Flex } from "@chakra-ui/react";
import React from "react";
import Moment from "react-moment";

import { EventResponseListDTO } from "../../model/eventModel";
import EventDetailLabel from "../EventDetailLabel";

type Variant = "primary" | "secondary" | "third";

interface IProps {
  event: EventResponseListDTO;
  variant: Variant;
}

const EventInfo = ({ event, variant }: IProps): React.ReactElement => {
  const { title, description, eventDate, eventTime, street } = event;

  return (
    <Box d="flex" width="100%" p="10px" mt="20px" flexDirection="column">
      {variant === "primary" && (
        <Text fontSize="md" fontWeight="bold">
          {title}
        </Text>
      )}
      {variant !== "third" && (
        <>
          <Text fontSize="sm" mb="10px">
            {description}
          </Text>
        </>
      )}
      <Flex justifyContent="space-between">
        {variant === "primary" && (
          <>
            <EventDetailLabel variant="primary">
              Data: <Moment format="DD/MM/YYYY">{eventDate}</Moment>
            </EventDetailLabel>
            <EventDetailLabel variant="primary">
              Hora: {eventTime?.substr(0, 5)}
            </EventDetailLabel>
            <EventDetailLabel
              variant="primary"
              isTruncated
              maxWidth="50%"
              title={street}
            >
              Local: {street}
            </EventDetailLabel>
          </>
        )}
        {(variant === "secondary" || variant === "third") && (
          <>
            <EventDetailLabel
              variant="secondary"
              icon="calendar-alt"
              alignItems="center"
            >
              {!!eventDate && <Moment format="DD/MM/YYYY">{eventDate}</Moment>}
            </EventDetailLabel>
            <EventDetailLabel
              variant="secondary"
              icon="clock"
              alignItems="center"
              ml="5px"
            >
              {eventTime?.substr(0, 5)}
            </EventDetailLabel>
            <EventDetailLabel
              variant="secondary"
              icon="map-marker-alt"
              alignItems="center"
              ml="5px"
              isTruncated
              maxWidth="50%"
              title={street}
            >
              {street}
            </EventDetailLabel>
          </>
        )}
      </Flex>
    </Box>
  );
};

export default EventInfo;
