/* eslint-disable react/require-default-props */
import { Box, BoxProps } from "@chakra-ui/react";
import { ReactNode } from "react";

interface HeaderProps extends BoxProps {
  variant?: "single" | "double";
  children?: ReactNode;
}

const mainColor = "#265DA2";
const secondaryColor = "#F9C201";

export const Header = ({
  variant = "single",
  children,
  ...props
}: HeaderProps): JSX.Element => {
  return (
    <Box width="100%" position="relative" {...props}>
      {children}

      {variant === "double" && (
        <svg
          viewBox="0 0 500 95"
          preserveAspectRatio="xMinYMin meet"
          style={{ position: "absolute" }}
        >
          <path
            d="M 500 80 C 350 150 150 -50 0 65 L 0 0 L 500 0 Z"
            style={{
              stroke: "none",
              fill: secondaryColor,
              position: "absolute",
            }}
          />
        </svg>
      )}

      <svg
        viewBox="0 0 500 95"
        preserveAspectRatio="xMinYMin meet"
        style={{
          filter:
            variant === "double"
              ? "drop-shadow(0 5px 2px rgba(0, 0, 0, 0.25))"
              : "",
        }}
      >
        <path
          d="M 500 50 C 350 150 150 -50 0 50 L 0 0 L 500 0 Z"
          style={{
            stroke: "none",
            fill: variant === "single" ? "white" : mainColor,
          }}
        />
      </svg>
    </Box>
  );
};
