import { Box, Img, Text } from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React from "react";
import ImageUploading, { ImageListType } from "react-images-uploading";

const InputFile = (props: {
  onChange: (values: any) => void;
}): React.ReactElement => {
  const [images, setImages] = React.useState([]);

  const { onChange } = props;

  const handleChange = (imageList: ImageListType) => {
    setImages(imageList as never[]);
    onChange(imageList);
  };

  return (
    <ImageUploading
      value={images}
      onChange={(imageList: ImageListType) => handleChange(imageList)}
    >
      {({ imageList, onImageUpload, isDragging, dragProps }) =>
        !!imageList && imageList.length > 0 ? (
          <Img
            src={imageList[0].dataURL}
            alt=""
            h="120px"
            w="120px"
            borderRadius="50%"
            opacity={isDragging ? "0.5" : "1"}
            onClick={onImageUpload}
            {...dragProps}
          />
        ) : (
          <Box
            as="label"
            p="5px"
            h="120px"
            w="120px"
            d="flex"
            htmlFor="file"
            border="3px dashed"
            borderRadius="50%"
            backgroundColor="gray.500"
            flexDirection="column"
            justifyContent="center"
            alignItems="center"
            opacity={isDragging ? "0.5" : "1"}
            onClick={onImageUpload}
            {...dragProps}
          >
            <>
              <Text color="gray.200" fontSize="sm" textAlign="center">
                Inserir foto perfil
              </Text>
              <FontAwesomeIcon color="white" icon="camera" />
            </>
          </Box>
        )
      }
    </ImageUploading>
  );
};

export default InputFile;
