/* eslint-disable no-alert */
/* eslint-disable @typescript-eslint/no-use-before-define */
import { Button, VStack, Text, BoxProps } from "@chakra-ui/react";
import React, { useState, useEffect } from "react";
import { Map as MapContainer, TileLayer, Marker, Popup } from "react-leaflet";
import { useHistory } from "react-router-dom";

import { EventResponseListDTO } from "../../model/eventModel";

interface IProps extends BoxProps {
  events: Array<EventResponseListDTO>;
}

const Map = ({ events }: IProps): React.ReactElement => {
  const [currentLocation, setCurrentLocation] = useState<GeolocationPosition>();
  const history = useHistory();

  useEffect(() => {
    getCurrentLocation();
  }, []);

  const getCurrentLocation = () => {
    if (navigator.geolocation) {
      navigator.geolocation.getCurrentPosition(
        (position: GeolocationPosition) => setCurrentLocation(position)
      );
    } else {
      alert("Geolocalização não é suportada.");
    }
  };

  return (
    <MapContainer
      center={[
        currentLocation?.coords.latitude || -30.0308043,
        currentLocation?.coords.longitude || -51.2278242,
      ]}
      zoom={10}
      style={{ width: "100vw", height: "calc(100vh - 150px)" }}
      zoomControl={false}
    >
      <TileLayer
        url={`https://api.mapbox.com/styles/v1/mapbox/light-v10/tiles/256/{z}/{x}/{y}@2x?access_token=${process.env.REACT_APP_ACCESS_TOKEN_MAP_BOX}`}
      />
      {events.map((event) => {
        const { id, title, latitude, longitude, userName } = event;
        return (
          event &&
          latitude &&
          longitude && (
            <Marker position={[Number(latitude), Number(longitude)]} key={id}>
              <Popup>
                <VStack>
                  <Text>{title}</Text>
                  <Text>Criador: {userName}</Text>
                  <Button onClick={() => history.push(`/events/${id}`)}>
                    Detalhes
                  </Button>
                </VStack>
              </Popup>
            </Marker>
          )
        );
      })}
    </MapContainer>
  );
};

export default Map;
