import {
  Flex,
  Text,
  Box,
  HStack,
  useToast,
  ToastPositionWithLogical,
  Image,
} from "@chakra-ui/react";
import React, { useState } from "react";

import { accept, deny } from "../../services/userService";
import Button from "../Button";

export interface RegistrationCardProps {
  id?: string;
  name?: string;
  phone?: string;
  email?: string;
  image?: string;
  findUsers: () => void;
}

const RegistrationCard = ({
  id = "id",
  name = "nome de empresa",
  phone = "telefone",
  email = "email",
  image = "uma imagem",
  findUsers,
}: RegistrationCardProps): React.ReactElement => {
  const [loading, setLoading] = useState(false);
  const toast = useToast();
  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };
  const acceptUser = async () => {
    setLoading(true);
    try {
      await accept(id);
      findUsers();
      showToastMessage(
        "Solicitacao aceita com sucesso!",
        "success",
        "top-right"
      );
    } catch (e: any) {
      showToastMessage(e, "error", "top-right");
    }
    setLoading(false);
  };

  const denyUser = async () => {
    setLoading(true);
    try {
      await deny(id);
      findUsers();
      showToastMessage(
        "Solicitacao negada com sucesso!",
        "success",
        "top-right"
      );
    } catch (e: any) {
      showToastMessage(e, "error", "top-right");
    }
    setLoading(false);
  };

  return (
    <Flex
      w="100%"
      h="190px"
      display="flex"
      flexDir="column"
      justifyContent="space-between"
      alignItems="center"
      border="1px solid"
      borderColor="blue.200"
      borderRadius="30px 0 0 0"
      boxSizing="border-box"
      p="10px"
      bgColor="white"
      boxShadow="lg"
    >
      <Box w="100%" display="flex" flexDirection="column" alignItems="center">
        <HStack width="100%" display="flex" px="24px">
          <Box
            overflow="hidden"
            borderRadius="50%"
            border="4px solid"
            borderColor="yellow.500"
            display="flex"
            maxW="720px"
            w="60px"
            height="60px"
          >
            <Image src={image} w="60px" h="60px" />
          </Box>
          <Text fontSize="14px" maxW="70%" color="#000">
            <b>{name}</b>
          </Text>
        </HStack>
        <Text fontSize="14px" color="#000">
          <b>{phone}</b>
        </Text>
        <Text fontSize="14px" color="#000">
          <b>{email}</b>
        </Text>
      </Box>
      <HStack>
        <Button
          theme="quaternary"
          width="140px"
          height="30px"
          onClick={denyUser}
          isLoading={loading}
          margin="0px 10px 0px 10px"
          fontSize="14px"
        >
          Negar
        </Button>
        <Button
          theme="secondary"
          width="140px"
          height="30px"
          onClick={acceptUser}
          isLoading={loading}
          margin="0px 10px 0px 10px"
          fontSize="14px"
        >
          Aceitar
        </Button>
      </HStack>
    </Flex>
  );
};

export default RegistrationCard;
