import { createContext, useState } from "react";

import {
  FilterDTO,
  loadFiltersLocalStorage,
  saveFiltersLocalStorage,
} from "../utils/utils";

interface FilterContextData {
  filters: FilterDTO;
  updateFilters: (filters: FilterDTO) => void;
}

export const FilterContext = createContext({} as FilterContextData);

interface FilterContextProviderProps {
  children: React.ReactNode;
}

export const FilterContextProvider = ({
  children,
}: FilterContextProviderProps): JSX.Element => {
  const [filters, setFilters] = useState(loadFiltersLocalStorage());

  const updateFilters = (newFilters: FilterDTO) => {
    saveFiltersLocalStorage(newFilters);
    setFilters({ ...newFilters });
  };

  return (
    <FilterContext.Provider value={{ filters, updateFilters }}>
      {children}
    </FilterContext.Provider>
  );
};
