import {
  Box,
  Img,
  Image,
  Text,
  Flex,
  Tag,
  useToast,
  ToastPositionWithLogical,
} from "@chakra-ui/react";
import React, { useEffect, useState } from "react";
import { useHistory } from "react-router-dom";

import defaultImage from "../../assets/default-event-image.png";
import logoImage from "../../assets/logo-1X.png";
import BottomMenu from "../../components/BottomMenu";
import EventInfo from "../../components/EventInfo";
import { Header } from "../../components/Header";
import SearchBar from "../../components/SearchBar";
import { EventResponseListDTO } from "../../model/eventModel";
import { findAllDonateEventsActive } from "../../services/eventService";

const AdminListEvent = (): React.ReactElement => {
  const [events, setEvents] = useState<Array<EventResponseListDTO>>([]);
  const [filteredEvents, setFilteredEvents] =
    useState<EventResponseListDTO[]>(events);
  const [search, setSearch] = React.useState("");

  const history = useHistory();
  const toast = useToast();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  useEffect(() => {
    (async () => {
      try {
        const response = await findAllDonateEventsActive();
        const foundEvents = response;

        setEvents(foundEvents);
        setFilteredEvents(foundEvents);
      } catch (e: any) {
        showToastMessage(e, "error", "top-right");
      }
    })();
  }, []);

  useEffect(() => {
    const filtered = events?.filter((event) => {
      const eventNameMatechesSearch = event.title
        ?.trim()
        .toLocaleLowerCase()
        .includes(search.trim().toLocaleLowerCase());

      return eventNameMatechesSearch;
    });

    setFilteredEvents(filtered);
  }, [search]);

  const handleClick = (id: string | undefined) => {
    if (id) history.push(`/list-events/${id}`);
  };

  return (
    <>
      <Header variant="double" position="fixed" zIndex="99">
        <Box id="first-name" isRequired width="100%" bg="#265DA2" mb="-1px">
          <Box
            display="flex"
            justifyContent="center"
            alignItems="center"
            maxW="720px"
            mx="auto"
            p="8px 8px 0 8px"
          >
            <Image src={logoImage} w="96px" h="96px" />

            <SearchBar
              value={search}
              onChange={(e) => setSearch(e.target.value)}
            />
          </Box>
        </Box>
      </Header>
      <Box
        h="calc(100vh - 50px)"
        overflowY="auto"
        pt={["180px", "240px"]}
        pb="10px"
      >
        <Flex
          w="100%"
          alignItems="center"
          justifyContent="center"
          direction="column"
        >
          <Text color="yellow.500" fontWeight="extrabold" textAlign="center">
            SOLICITAÇÕES EM ABERTO:
          </Text>
        </Flex>
        {filteredEvents.length > 0 ? (
          filteredEvents.map((event: EventResponseListDTO) => (
            <Box key={event.id} onClick={() => handleClick(event.id)}>
              <Flex justifyContent="flex-end" w="100vw">
                <Tag
                  bgColor="yellow.500"
                  color="white"
                  borderRightRadius="0"
                  position="relative"
                  top="5px"
                  zIndex="10"
                  fontSize={["20px", "24px"]}
                >
                  {event.title}
                </Tag>
              </Flex>
              <Img
                w="100vw"
                h="250px"
                src={
                  event.images && event.images.length > 0
                    ? event.images[0]
                    : defaultImage
                }
                alt="imagem"
              />
              <EventInfo event={event} variant="third" />
            </Box>
          ))
        ) : (
          <Box
            w="100%"
            h="50vh"
            display="flex"
            alignItems="center"
            justifyContent="center"
          >
            <Text>Não há solicitações em aberto.</Text>
          </Box>
        )}
      </Box>
      <BottomMenu defaultIndex={0} />
    </>
  );
};
export default AdminListEvent;
