import { Img, Flex, HStack, Box } from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React from "react";
import ImageUploading, { ImageListType } from "react-images-uploading";

interface IProps {
  onChange: (values: any) => void;
  max: number;
}

const InputImages = ({ onChange, max = 3 }: IProps): React.ReactElement => {
  const [images, setImages] = React.useState<ImageListType>([]);

  const handleChange = (imageList: ImageListType) => {
    setImages(imageList);
    onChange(imageList);
  };

  return (
    <ImageUploading
      multiple
      value={images}
      onChange={handleChange}
      maxNumber={max}
      dataURLKey="data_url"
    >
      {({ imageList, onImageUpload, onImageRemove, isDragging, dragProps }) => (
        <HStack d="flex" alignItems="flex-end">
          {imageList.map((image, index) => (
            <Box key={index}>
              <Flex justifyContent="end" w="80%" h="20px">
                <FontAwesomeIcon
                  color="red"
                  icon="minus-square"
                  title="Remover"
                  onClick={() => onImageRemove(index)}
                />
              </Flex>
              <Img
                src={image.data_url}
                alt=""
                h={{ sm: "60px", md: "100px", lg: "120px" }}
                w={{ sm: "60px", md: "100px", lg: "120px" }}
                borderRadius="5px"
                flexDir="column"
                justifyContent="center"
                alignItems="center"
              />
            </Box>
          ))}
          <Flex
            style={isDragging ? { color: "red" } : undefined}
            onClick={onImageUpload}
            opacity={isDragging ? "0.5" : "1"}
            as="label"
            p="5px"
            h={{ sm: "40px", md: "60px", lg: "80px" }}
            w={{ sm: "40px", md: "60px", lg: "80px" }}
            borderRadius="10px"
            bgColor="gray.300"
            flexDir="column"
            justifyContent="center"
            alignItems="center"
            {...dragProps}
          >
            <FontAwesomeIcon color="#f9c201" icon="camera" title="Adicionar" />
          </Flex>
        </HStack>
      )}
    </ImageUploading>
  );
};

export default InputImages;
