/* eslint-disable jsx-a11y/label-has-associated-control */
import {
  Input,
  Stack,
  useToast,
  Text,
  Box,
  Select,
  ToastPositionWithLogical,
} from "@chakra-ui/react";
import React, { useState } from "react";
import { ImageListType } from "react-images-uploading";
import { useHistory } from "react-router-dom";
import { setTimeout } from "timers";

import AutocompleteGeocoding from "../../components/AutocompleteGeocoding";
import BottomMenu from "../../components/BottomMenu";
import Button from "../../components/Button";
import { EventRequest } from "../../model/eventModel";
import { createEvent } from "../../services/eventService";
import InputImages from "./InputImages";

const CreateEvent = (): React.ReactElement => {
  const [loading, setLoading] = useState(false);
  const [type, setType] = useState("");
  const [title, setTitle] = useState("");
  const [description, setDescripdtion] = useState("");
  const [phone, setPhone] = useState("");
  const [startDate, setStartDate] = useState("");
  const [endDate, setEndDate] = useState("");
  const [street, setStreet] = useState("");
  const [images, setImages] = useState<Array<string>>([]);
  const [coordinates, setCoordinates] =
    React.useState<google.maps.LatLngLiteral>({ lat: 0, lng: 0 });

  const history = useHistory();
  const toast = useToast();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  const onSubmit = async (e: React.SyntheticEvent) => {
    e.preventDefault();
    setLoading(true);
    const event = new EventRequest(
      title,
      description,
      phone,
      type,
      startDate,
      endDate,
      street,
      images,
      coordinates.lat,
      coordinates.lng
    );

    try {
      await createEvent(event);
      showToastMessage(
        "Evento cadastrado com sucesso!",
        "success",
        "top-right"
      );
      setTimeout(() => {
        history.push("/events");
      }, 1000);
    } catch (e: any) {
      showToastMessage(e, "error", "top-right");
      setLoading(false);
    }
  };

  const uploadImages = (e: ImageListType) => {
    const images: Array<string> = e.map((image) => image.data_url);
    setImages(images);
  };

  const setAddress = (
    street: string,
    coordinates: google.maps.LatLngLiteral
  ) => {
    setStreet(street);
    setCoordinates(coordinates);
  };

  return (
    <Box
      d="flex"
      flexDirection="column"
      alignItems="center"
      justifyContent="space-evenly"
      h="calc(100vh - 50px)"
      overflowY="auto"
    >
      <Text color="yellow.500" fontWeight="extrabold" textAlign="center">
        CRIAR EVENTO
      </Text>

      <Stack
        as="form"
        alignItems="center"
        onSubmit={(e) => onSubmit(e)}
        w={["80%", "60%", "50%"]}
      >
        <InputImages onChange={uploadImages} max={3} />

        <Input
          placeholder="Adicione um título ao seu evento"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setTitle(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
          maxLength={150}
        />
        <Input
          placeholder="Descreva brevemente sobre o que se trata"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setDescripdtion(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
          maxLength={250}
        />

        <Input
          type="tel"
          placeholder="Telefone para contato"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setPhone(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
        />

        <Select
          borderColor="blue.200"
          placeholder="Selecione..."
          onChange={(e) => setType(e.target.value)}
          _hover={{ borderColor: "blue.200" }}
        >
          <option value="DONATION">Doação</option>
          <option value="ACTION">Ação voluntária</option>
        </Select>
        <Input
          placeholder="Data de início"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setStartDate(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
          type="datetime-local"
        />

        <Input
          placeholder="Data de término"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setEndDate(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
          type="datetime-local"
        />

        <AutocompleteGeocoding setLocation={setAddress} />

        <Button
          isLoading={loading}
          theme="secondary"
          w="60%"
          type="submit"
          _hover={{ background: "yellow.500" }}
          _active={{ background: "yellow.500" }}
        >
          Criar Evento
        </Button>
      </Stack>
      <BottomMenu defaultIndex={2} />
    </Box>
  );
};
export default CreateEvent;
