/* eslint-disable no-restricted-globals */
import { Box, Flex, Tag, useToast, SlideFade, Fade } from "@chakra-ui/react";
import React, { useEffect, useState } from "react";
import { useHistory, useParams } from "react-router-dom";

import BottomMenu from "../../components/BottomMenu";
import Button from "../../components/Button";
import Carousel from "../../components/Carousel";
import EventInfo from "../../components/EventInfo";
import * as Header from "../../components/Header";
import SeeTasks from "../../components/SeeTasks/index.";
import StaticMap from "../../components/StaticMap";
import { EventDetailsResponseDTO } from "../../model/eventModel";
import {
  cancelParticipate,
  findEventDetails,
  participateEvent,
} from "../../services/eventService";
import { showSweetAlertConfirm } from "../../utils/utils";
import TaskManager from "../TaskManager";

interface RouteParams {
  id: string;
}

const EventDetails = (): React.ReactElement => {
  const [event, setEvent] = useState<EventDetailsResponseDTO>({
    latitude: "",
    longitude: "",
    taskProgress: 0,
  });
  const [openTaskManager, setOpenTaskMaganer] = useState(false);
  const params = useParams<RouteParams>();
  const { id } = params;
  const history = useHistory();
  const toast = useToast();

  const findEvent = () => {
    (async () => {
      const response = await findEventDetails(id);
      setEvent(response.data);
    })();
  };

  useEffect(() => {
    findEvent();
  }, []);

  const handleParticipate = async (): Promise<void> => {
    let response = null;
    let message = "";
    let callback = null;
    try {
      let title = "";
      const showSuccessMessage = (message: string) => {
        toast({
          title: message,
          status: "success",
          position: "top-right",
          isClosable: true,
        });
      };

      if (!event.loggedUserParticipate) {
        title = "Deseja participar do evento?";
        callback = async () => {
          response = await participateEvent(id);
          setEvent(response.data);
          message = "Participação efetuada com sucesso!";
          showSuccessMessage(message);
        };
      } else {
        title = "Deseja deixar de participar do evento?";
        callback = async () => {
          response = await cancelParticipate(id);
          setEvent(response.data);
          message = "Participação cancelada!";
          showSuccessMessage(message);
        };
      }

      showSweetAlertConfirm(title, "", "question", callback);
    } catch (e: any) {
      toast({
        title: e,
        status: "error",
        position: "top-right",
        isClosable: true,
      });
    }
  };

  return (
    (!!openTaskManager && (
      <>
        <SlideFade in={openTaskManager} offsetY="20px">
          <TaskManager
            setOpenTaskMaganer={setOpenTaskMaganer}
            event={event}
            findEvent={findEvent}
          />
        </SlideFade>
      </>
    )) || (
      <Fade in>
        <Header.Header variant="double" position="fixed" zIndex="99" />
        <Box
          h="calc(100vh - 50px)"
          overflowY="auto"
          pt={["55px", "125px"]}
          pb="10px"
        >
          <Button
            theme="secondary"
            variant="back"
            onClick={history.goBack}
            _hover={{ background: "yellow.500" }}
            _active={{ background: "yellow.500" }}
          />

          <Flex justifyContent="flex-end" w="100vw">
            <Tag
              bgColor="yellow.500"
              color="white"
              borderRightRadius="0"
              position="relative"
              top="5px"
              zIndex="10"
              fontSize={["20px", "24px"]}
            >
              {event.title}
            </Tag>
          </Flex>

          <Carousel images={event.images} h={["200px", "300px"]} />

          <EventInfo event={event} variant="secondary" />

          <Box
            bgColor="yellow.500"
            h={["7px"]}
            w={["calc(100vw - 20px)"]}
            mr="10px"
            ml="10px"
            mt="10px"
            borderRadius="10px"
          />

          <SeeTasks
            setOpenTaskMaganer={setOpenTaskMaganer}
            loggedUserParticipate={event.loggedUserParticipate || false}
            taskProgress={event.taskProgress}
          />

          <Flex
            flexDir="column"
            alignItems="center"
            justifyContent="center"
            mt="40px"
          >
            <StaticMap
              lat={event.latitude || ""}
              lng={event.longitude || ""}
              w="300px"
              h="200px"
              marginBottom="10px"
              borderRadius="10px"
              cursor="pointer"
            />

            <Button
              theme="secondary"
              onClick={() => {
                handleParticipate();
              }}
              _hover={{ background: "yellow.500" }}
              _active={{ background: "yellow.500" }}
            >
              {!event.loggedUserParticipate
                ? "PARTICIPAR!"
                : "CANCELAR PARTICIPAÇÃO!"}
            </Button>
          </Flex>
        </Box>
        <BottomMenu defaultIndex={-1} />
      </Fade>
    )
  );
};
export default EventDetails;
