import {
  Stack,
  Input,
  InputGroup,
  InputRightElement,
  useToast,
  Box,
  Link,
  ToastPositionWithLogical,
} from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import jwt from "jsonwebtoken";
import React, { useState } from "react";
import { useHistory, Link as ReachLink } from "react-router-dom";

import Button from "../../components/Button";
import api from "../../services/api";
import { getLoggedUser } from "../../services/userService";
import {
  BackgroundSM,
  BackgroundMD,
  BackgroundLG,
  BackgroundXL,
} from "../../utils/background";

const Login = (): React.ReactElement => {
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [showPassword, setShowPassword] = useState(false);
  const [loading, setLoading] = useState(false);
  const handleClick = () => setShowPassword(!showPassword);
  const toast = useToast();

  const history = useHistory();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  const login = async (event: React.SyntheticEvent) => {
    event.preventDefault();
    setLoading(true);
    try {
      const user = await api.post("/users/login", {
        email,
        password,
      });
      const token = user.headers.authorization;
      window.localStorage.setItem("token", token.split(" ")[1]);
      const decodedToken: any = jwt.decode(token.split(" ")[1]);
      const path =
        decodedToken.role === "ROLE_ADMIN" ? "/list-events" : "/events";

      const loggedUser = await getLoggedUser();
      window.localStorage.setItem("@mutirao_user", JSON.stringify(loggedUser));

      if (!loggedUser.active) {
        showToastMessage(
          "Solicitação de cadastro pendente!",
          "error",
          "top-right"
        );
        setLoading(false);
        return;
      }

      history.push(path);
    } catch (e) {
      showToastMessage("Usuário ou senha incorretos!", "error", "top-right");
      setLoading(false);
    }
  };

  return (
    <Box
      h="100vh"
      bgImage={[BackgroundSM, BackgroundMD, BackgroundLG, BackgroundXL]}
      bgRepeat="no-repeat"
      bgSize="cover"
      bgPosition="top"
    >
      <Box
        d="flex"
        flexDirection="column"
        alignItems="center"
        justifyContent="center"
        h="100vh"
      >
        <div style={{ height: "30%" }} />
        <Stack
          as="form"
          onSubmit={(e) => login(e)}
          spacing={["10", "12"]}
          w={["80%", "40%", "30%"]}
        >
          <Input
            placeholder="E-mail"
            variant="flushed"
            onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
              setEmail(e.target.value)
            }
            color="white"
          />

          <InputGroup size="md">
            <Input
              pr="4.5rem"
              type={showPassword ? "text" : "password"}
              placeholder="Senha"
              variant="flushed"
              onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
                setPassword(e.target.value)
              }
              color="white"
            />
            <InputRightElement width="4.5rem">
              {showPassword ? (
                <FontAwesomeIcon
                  icon="eye"
                  onClick={handleClick}
                  color="white"
                />
              ) : (
                <FontAwesomeIcon
                  icon="eye-slash"
                  onClick={handleClick}
                  color="white"
                />
              )}
            </InputRightElement>
          </InputGroup>

          <Box
            d="flex"
            flexDirection="column"
            alignItems="center"
            justifyContent="center"
            w="100%"
          >
            <Button
              isLoading={loading}
              theme="primary"
              w="90%"
              type="submit"
              _hover={{ background: "blue.500" }}
            >
              Logar
            </Button>
            <Link
              as={ReachLink}
              to="/forgot-password"
              style={{ opacity: "0.59" }}
              color="white"
            >
              Esqueci minha senha
            </Link>
          </Box>

          <Box
            d="flex"
            flexDirection="column"
            alignItems="center"
            justifyContent="center"
            w="100%"
          >
            <Button
              theme="tertiary"
              onClick={() => history.push("/register")}
              w="90%"
            >
              Criar conta
            </Button>
            <Link
              as={ReachLink}
              to="/events"
              style={{ opacity: "0.59" }}
              color="white"
            >
              Continuar como convidado
            </Link>
          </Box>
        </Stack>
      </Box>
    </Box>
  );
};

export default Login;
