import { Box, Text, VStack } from "@chakra-ui/react";
import React, { useEffect, useState } from "react";

import BottomMenu from "../../components/BottomMenu";
import { Header } from "../../components/Header";
import Map from "../../components/LeafletMap";
import SearchBar from "../../components/SearchBar";
import { EventResponseListDTO } from "../../model/eventModel";
import { findActiveEvent } from "../../services/eventService";

const MapPage = (): React.ReactElement => {
  const [events, setEvents] = useState<Array<EventResponseListDTO>>([]);
  const [filteredEvents, setFilteredEvents] =
    useState<EventResponseListDTO[]>(events);
  const [search, setSearch] = React.useState("");

  useEffect(() => {
    (async () => {
      const response = await findActiveEvent();
      const foundEvents = response;

      setEvents(foundEvents);
      setFilteredEvents(foundEvents);
    })();
  }, []);

  useEffect(() => {
    const filtered = events.filter((event) => {
      const eventNameMatechesSearch = event.title
        ?.trim()
        .toLocaleLowerCase()
        .includes(search.trim().toLocaleLowerCase());

      return eventNameMatechesSearch;
    });

    setFilteredEvents(filtered);
  }, [search]);

  return (
    <>
      <Header variant="double" position="fixed" zIndex={999}>
        <VStack
          w="100%"
          h="100px"
          p="0px 20px 0px 20px"
          justifyContent="center"
          bgColor="rgb(38, 93, 162)"
        >
          <Text color="yellow.500" fontWeight="extrabold">
            EVENTOS ATIVOS
          </Text>
          <SearchBar
            value={search}
            onChange={(e) => setSearch(e.target.value)}
          />
        </VStack>
      </Header>
      <Box h="100px" />
      <Map w="100vw" h="calc(100vh - 150px)" events={filteredEvents} />
      <BottomMenu defaultIndex={1} />
    </>
  );
};
export default MapPage;
