import {
  Flex,
  Box,
  Input,
  Stack,
  Text,
  Image,
  useToast,
  ToastPositionWithLogical,
} from "@chakra-ui/react";
import React, { useEffect, useState } from "react";
import { useHistory, useParams } from "react-router-dom";

import BottomMenu from "../../components/BottomMenu";
import Button from "../../components/Button";
import { User } from "../../model/userModel";
import { findById } from "../../services/userService";
import {
  showSweetAlertConfirm,
  getLoggedUserFromLocalStorage,
} from "../../utils/utils";

interface RouteParams {
  id: string;
}

const Home = (): React.ReactElement => {
  const history = useHistory();
  const [user, setuser] = useState<User>();
  const [loggedUser, setLoggedUser] = useState<User>();
  const params = useParams<RouteParams>();
  const { id } = params;
  const toast = useToast();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  useEffect(() => {
    (async () => {
      try {
        const response = await findById(id);
        setuser(response.data);
        setLoggedUser(getLoggedUserFromLocalStorage());
      } catch (e: any) {
        showToastMessage(e, "error", "top-right");
      }
    })();
  }, []);

  const logout = () => {
    localStorage.clear();
    history.push("/login");
  };

  const leave = () => {
    showSweetAlertConfirm(
      "Tem certeza que deseja sair?",
      "",
      "question",
      logout
    );
  };

  return (
    <Flex
      h="calc(100vh - 50px)"
      p="10px"
      direction="column"
      alignItems="center"
      justifyContent="space-evenly"
      overflowY="auto"
    >
      {!!user && (
        <>
          <Stack display="flex" alignItems="center" flexDirection="column">
            <Text fontWeight="extrabold" color="yellow.500">
              PERFIL DO USUÁRIO
            </Text>
            <Box
              w="226px"
              h="226px"
              borderRadius="50%"
              overflow="hidden"
              border="12px solid"
              borderColor="blue.200"
              display="flex"
              justifyContent="center"
              alignItems="center"
              maxW="720px"
              mx="auto"
            >
              <Image src={user?.image} w="226px" h="226px" />
            </Box>
          </Stack>

          <Stack
            spacing="16px"
            justifyContent="center"
            alignItems="center"
            w={["80%", "40%", "30%"]}
          >
            <Box w="100%" display="flex" flexDirection="column">
              <Text fontWeight="extrabold" color="blue.200">
                Nome
              </Text>
              <Input
                w="100%"
                as="text"
                border="1px solid"
                borderRadius="8px"
                p="8px 0 8px 15px"
                borderColor="blue.200"
                _hover={{ borderColor: "blue.200" }}
              >
                {user?.name}
              </Input>
            </Box>

            <Box w="100%" display="flex" flexDirection="column">
              <Text fontWeight="extrabold" color="blue.200">
                Documento
              </Text>
              <Input
                w="100%"
                as="text"
                border="1px solid"
                borderRadius="8px"
                p="8px 0 8px 15px"
                borderColor="blue.200"
                _hover={{ borderColor: "blue.200" }}
              >
                {user?.document}
              </Input>
            </Box>
            <Box w="100%" display="flex" flexDirection="column">
              <Text fontWeight="extrabold" color="blue.200">
                Telefone
              </Text>
              <Input
                w="100%"
                as="text"
                border="1px solid"
                borderRadius="8px"
                p="8px 0 8px 15px"
                borderColor="blue.200"
                _hover={{ borderColor: "blue.200" }}
              >
                {user?.phone}
              </Input>
            </Box>
            <Box w="100%" display="flex" flexDirection="column">
              <Text fontWeight="extrabold" color="blue.200">
                E-mail
              </Text>
              <Input
                w="100%"
                as="text"
                border="1px solid"
                borderRadius="8px"
                p="8px 0 8px 15px"
                borderColor="blue.200"
                _hover={{ borderColor: "blue.200" }}
              >
                {user?.email}
              </Input>
            </Box>

            {loggedUser?.id === user?.id && (
              <Button
                theme="secondary"
                w="60%"
                onClick={leave}
                _hover={{ background: "yellow.400" }}
                _active={{ background: "yellow.400" }}
              >
                Sair
              </Button>
            )}
          </Stack>
        </>
      )}

      <BottomMenu defaultIndex={3} />
    </Flex>
  );
};

export default Home;
