/* eslint-disable jsx-a11y/label-has-associated-control */
import {
  Flex,
  Input,
  Select,
  Stack,
  Text,
  useToast,
  ToastPositionWithLogical,
} from "@chakra-ui/react";
import React, { useState } from "react";
import { ImageListType } from "react-images-uploading";
import { useHistory } from "react-router-dom";

import BottomMenu from "../../components/BottomMenu";
import Button from "../../components/Button";
import InputFile from "../../components/InputFile";
import PasswordInput from "../../components/PasswordInput";
import { UserRegister } from "../../model/userModel";
import { createUser } from "../../services/userService";

const Register = (): React.ReactElement => {
  const [loading, setLoading] = useState(false);
  const [name, setName] = useState("");
  const [document, setDocument] = useState("");
  const [type, setType] = useState("");
  const [phone, setPhone] = useState("");
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [image, setImage] = useState("");
  const toast = useToast();
  const history = useHistory();

  const showToastMessage = (
    title: string,
    status: "info" | "warning" | "success" | "error" | undefined,
    position: ToastPositionWithLogical | undefined
  ) => {
    toast({
      title,
      status,
      position,
      isClosable: true,
    });
  };

  const signUp = async (event: React.SyntheticEvent) => {
    setLoading(true);
    event.preventDefault();
    const user = new UserRegister(
      name,
      type,
      document,
      phone,
      email,
      password,
      image
    );

    try {
      await createUser(user);
      const message =
        type === "VOLUNTARY"
          ? "Usuário cadastrado com sucesso!"
          : "Solicitação de cadastro enviada com sucesso!";
      showToastMessage(message, "success", "top-right");
      setTimeout(() => {
        history.push("/login");
      }, 1000);
    } catch (e: any) {
      showToastMessage(e, "error", "top-right");
    }
    setLoading(false);
  };

  const uploadImage = (e: ImageListType) => {
    if (e && e.length > 0 && e[0].dataURL) {
      setImage(e[0].dataURL);
    }
  };

  return (
    <Flex
      direction="column"
      alignItems="center"
      justifyContent="space-evenly"
      h="calc(100vh - 50px)"
      p="10px"
      overflowY="auto"
    >
      <Text fontWeight="extrabold" color="yellow.500">
        CADASTRO DE USUÁRIO
      </Text>
      <InputFile onChange={uploadImage} />
      <Stack
        as="form"
        justifyContent="center"
        alignItems="center"
        onSubmit={(e) => signUp(e)}
        w={["80%", "40%", "30%"]}
      >
        <Input
          placeholder="Nome completo"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setName(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
        />
        <Select
          borderColor="blue.200"
          placeholder="Selecione..."
          onChange={(e) => setType(e.target.value)}
          _hover={{ borderColor: "blue.200" }}
        >
          <option value="VOLUNTARY">Doador voluntário</option>
          <option value="ENTITY">Entidade recebedora</option>
        </Select>
        <Input
          placeholder="CPF/CNPJ (somente números)"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setDocument(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
        />
        <Input
          placeholder="DDD+ telefone"
          borderColor="blue.200"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setPhone(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
        />
        <Input
          placeholder="E-mail"
          borderColor="blue.200"
          type="email"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setEmail(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
        />
        <PasswordInput
          variant="outline"
          onChange={setPassword}
          placeholder="Senha"
          borderColor="blue.200"
          _hover={{ borderColor: "blue.200" }}
        />
        <Button
          isLoading={loading}
          theme="secondary"
          w="60%"
          type="submit"
          _hover={{ background: "yellow.500" }}
          _active={{ background: "yellow.500" }}
        >
          Criar Conta
        </Button>
      </Stack>
      <BottomMenu defaultIndex={3} />
    </Flex>
  );
};
export default Register;
