import { Input, Box, Flex, Text, useToast } from "@chakra-ui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { useState } from "react";
import { useParams } from "react-router-dom";

import Button from "../../components/Button";
import TaskCard from "../../components/TaskCard";
import { EventDetailsResponseDTO } from "../../model/eventModel";
import { createTask } from "../../services/taskService";

interface IProps {
  setOpenTaskMaganer: (value: boolean) => void;
  event: EventDetailsResponseDTO;
  findEvent: () => void;
}

interface RouteParams {
  id: string;
}

const TaskManager = ({
  setOpenTaskMaganer,
  event,
  findEvent,
}: IProps): React.ReactElement => {
  const [description, setDescription] = useState("");
  const [loading, setLoading] = useState(false);
  const params = useParams<RouteParams>();
  const { id } = params;
  const toast = useToast();
  const { tasks } = event;

  const create = async () => {
    if (loading) return;
    setLoading(true);
    try {
      await createTask(id, description);

      findEvent();
      setDescription("");

      toast({
        title: "Tarefa criada com sucesso!",
        status: "success",
        position: "top-right",
        isClosable: true,
      });
    } catch (e: any) {
      toast({
        title: e,
        status: "error",
        position: "top-right",
        isClosable: true,
      });
    }
    setLoading(false);
  };
  return (
    <Box>
      <Flex w="100vw" p="10px" justifyContent="center">
        <Box w="20%">
          <Button
            theme="secondary"
            variant="back"
            onClick={() => setOpenTaskMaganer(false)}
            _hover={{ background: "yellow.500" }}
            _active={{ background: "yellow.500" }}
          />
        </Box>
        <Flex w="80%" alignItems="center" justifyContent="center">
          <Text color="yellow.500" fontWeight="extrabold" textAlign="center">
            TAREFAS DO EVENTO
          </Text>
        </Flex>
      </Flex>

      <Flex alignItems="center" p="10px" mt="20px">
        <Input
          placeholder="Descrição da tarefa"
          borderColor="blue.200"
          mr="5px"
          value={description}
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setDescription(e.target.value)
          }
          _hover={{ borderColor: "blue.200" }}
          maxLength={150}
        />

        <Button
          theme="secondary"
          h="34px"
          w="34px"
          borderRadius="50%"
          bgColor="transparent"
          onClick={create}
          isDisabled={loading}
        >
          <FontAwesomeIcon
            icon="plus-circle"
            size="2x"
            color="#f9c201"
            cursor="pointer"
          />
        </Button>
      </Flex>

      {tasks?.map((task, key) => (
        <Flex key={key} justifyContent="flex-end" mb="30px">
          <TaskCard
            eventId={id}
            task={task}
            eventOwner={event.user}
            eventType={event.type}
            findEvent={findEvent}
          />
        </Flex>
      ))}
    </Box>
  );
};

export default TaskManager;
