/* eslint-disable react/require-default-props */
// import jwt from "jsonwebtoken";
import jwt from "jsonwebtoken";
import React from "react";
import {
  BrowserRouter as Router,
  Redirect,
  Route,
  Switch,
  useLocation,
} from "react-router-dom";

import AdminListEvent from "./pages/AdminListEvent";
import AdminListEventDetails from "./pages/AdminListEventDetails";
import CreateEvent from "./pages/CreateEvent";
import EventDetails from "./pages/EventDetails";
import ListEvent from "./pages/ListEvent";
import Login from "./pages/Login";
import MapPage from "./pages/Map";
import Profile from "./pages/Profile";
import Register from "./pages/Register";
import RegistrationRequest from "./pages/RegistrationRequest";
import { isAuthenticated } from "./utils/authentication";

export enum UserType {
  VOLUNTARY,
  ENTITY,
  ADMIN,
}
interface IProps {
  children: React.ReactNode;
  type?: UserType;
  [x: string]: any;
}

const AdminRoute = ({ children, ...rest }: IProps) => {
  const location = useLocation();
  if (!isAuthenticated()) {
    return (
      <Redirect
        to={{
          pathname: "/login",
          state: { from: location.pathname + location.search },
        }}
      />
    );
  }

  const token = window.localStorage.getItem("token");
  if (token) {
    const decodedToken: any = jwt.decode(token);
    if (decodedToken.role !== "ROLE_ADMIN") {
      return <h1>Forbidden</h1>;
    }
  }

  return (
    <div>
      <Route {...rest}>{children}</Route>
    </div>
  );
};

const PrivateRoute = ({ children, ...rest }: IProps) => {
  const location = useLocation();
  if (!isAuthenticated()) {
    return (
      <Redirect
        to={{
          pathname: "/login",
          state: { from: location.pathname + location.search },
        }}
      />
    );
  }

  return (
    <div>
      <Route {...rest}>{children}</Route>
    </div>
  );
};

export const Routes = (): React.ReactElement => {
  return (
    <Router>
      <Switch>
        <Route path="/login">
          <Login />
        </Route>
        <Route exact path="/">
          <Redirect to="/events" />
        </Route>
        <Route exact path="/events">
          <ListEvent />
        </Route>
        <Route path="/map">
          <MapPage />
        </Route>
        <PrivateRoute path="/create-event">
          <CreateEvent />
        </PrivateRoute>
        <PrivateRoute path="/profile/:id">
          <Profile />
        </PrivateRoute>
        <Route path="/register">
          <Register />
        </Route>
        <AdminRoute path="/registration-request">
          <RegistrationRequest />
        </AdminRoute>
        <PrivateRoute path="/events/:id">
          <EventDetails />
        </PrivateRoute>
        <AdminRoute exact path="/list-events">
          <AdminListEvent />
        </AdminRoute>
        <AdminRoute path="/list-events/:id">
          <AdminListEventDetails />
        </AdminRoute>
      </Switch>
    </Router>
  );
};
