import axios from "axios";

const api = axios.create({
  baseURL: process.env.REACT_APP_API_BASE_URL,
});

api.interceptors.request.use(async (config) => {
  const token = window.localStorage.getItem("token");
  if (token) {
    // eslint-disable-next-line no-param-reassign
    config.headers.authorization = token;
  }
  return config;
});

api.interceptors.response.use(
  (response) => {
    return response;
  },
  (error) => {
    if (error.response) {
      if (typeof error.response.data === "string") {
        throw error.response.data;
      }
      throw error.response.data.error;
    }
    if (error.request) {
      throw error.request;
    }
    throw error.message;
  }
);

export default api;
